require 'nokogiri'
require 'uri'

module Sekureco

  class HtmlPage
    def initialize html_doc
      @html_doc = Nokogiri::HTML(html_doc)
    end

    def content
      @html_doc.to_html
    end

    def body
      @html_doc.css("body").to_html
    end

    def parsed_body black_list = []
      html = self.body.dup
      black_list.each { |word| html.gsub! word, "" }
      html.gsub(/(name=\"authenticity_token\" value=\".*\"|authenticity_token=[^;]*;|\?([^=]+=[^\&\"]+)+)/, '')
    end

    def links
      @html_doc.css("a")
    end

    def scripts_with filter
      @html_doc.css("script.#{filter}")
    end

    def forms
      @html_doc.css("form")
    end

    def has_forms?
      @html_doc.at_css("form")
    end

    def csrf_token
      self.has_csrf_tokens? ? @html_doc.css('meta[name="csrf-token"]').first['content'] : ''
    end

    def has_csrf_tokens?
      !@html_doc.css('meta[name="csrf-token"]').empty?
    end

    def to_s
      self.parsed_body
    end

    def log
      Sekureco.logger.info(self.to_s)
      Sekureco.logger.info("\n#{"=" * 80}\n")
    end
  end

end
