require 'net/http'
require 'uri'

module Sekureco

  class HttpClient

    include Net

    def initialize
      @cookies = {}
    end

    def get uri
      Sekureco.logger.info "GET #{uri.to_s}"
      HTTP.start(uri.host, uri.port) do |http|
        get_request = HTTP::Get.new uri
        get_request['Cookie'] = cookies
        @curr_response = http.request(get_request)
        set_cookies
      end
      @curr_response
    end

    def post uri, params = {}
      Sekureco.logger.info "POST #{uri.to_s}"
      Sekureco.logger.info "params: #{params}"
      HTTP.start(uri.host, uri.port) do |http|
        post_request = HTTP::Post.new uri
        post_request['Cookie'] = cookies
        post_request.set_form_data(params)
        @curr_response = http.request(post_request)
        set_cookies
      end
      @curr_response
    end

    private

      def set_cookies
        unless @curr_response.nil?
          new_cookies = @curr_response.get_fields('set-cookie')
          unless new_cookies.nil?
            new_cookies.each do |cookie|
              key, value = cookie.split("; ").first.split("=")
              @cookies[key] = value
            end
          end
        end
      end

      def cookies
        cookies_field = []
        @cookies.each do |k, v|
          cookies_field << "#{k}=#{v}"
        end
        cookies_field.join("; ")
      end
  end

end
